@@ -2,7 +2,7 @@
 
 package Dancer::Plugin::Authorize;
 BEGIN {
-  $Dancer::Plugin::Authorize::VERSION = '0.10';
+  $Dancer::Plugin::Authorize::VERSION = '0.1001';
 }
 use strict;
 use warnings;
@@ -117,7 +117,7 @@ Dancer::Plugin::Authorize - Dancer Authentication, Security and Role-Based Acces
 
 =head1 VERSION
 
-version 0.10
+version 0.1001
 
 =head1 SYNOPSIS
 
@@ -166,9 +166,13 @@ Dancer::Plugin::Authorize exports the auth() keyword:
     $auth->errors()                 # authentication errors if any
     $auth->revoke()                 # revoke authorization (logout)
 
-The Dancer::Plugin::Authorize authentication framework relies on the L<Dancer::Plugin::Authorize::Credentials>
-namespace to do the actual authentication, and likewise relies on the L<Dancer::Plugin::Authorize::Permissions>
-namespace to handle access control.
+The Dancer::Plugin::Authorize authentication framework relies on the
+L<Dancer::Plugin::Authorize::Credentials> namespace to do the actual
+authentication, and likewise relies on the L<Dancer::Plugin::Authorize::Permissions>
+namespace to handle access control. The following configuration example is based on
+L<Dancer::Plugin::Authorize::Credentials::Config> and L<Dancer::Plugin::Authorize::Permissions>.
+This framework also ship with L<Dancer::Plugin::Authorize::Credentials::SQLite>,
+L<Dancer::Plugin::Authorize::Credentials::MySQL>, L<Dancer::Plugin::Authorize::Credentials::PostrgeSQL>.
 
 =head1 CONFIGURATION
 
@@ -213,7 +217,7 @@ namespace to handle access control.
 
 =head1 AUTHOR
 
-  Al Newkirk <awncorp@cpan.org>
+Al Newkirk <awncorp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
